@@ -41,6 +41,7 @@
 
 G_BEGIN_DECLS
 
+
 #define BRASERO_TYPE_DATA_PROJECT             (brasero_data_project_get_type ())
 #define BRASERO_DATA_PROJECT(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), BRASERO_TYPE_DATA_PROJECT, BraseroDataProject))
 #define BRASERO_DATA_PROJECT_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), BRASERO_TYPE_DATA_PROJECT, BraseroDataProjectClass))
@@ -154,7 +155,7 @@ brasero_data_project_add_empty_directory (BraseroDataProject *project,
 					  BraseroFileNode *parent);
 BraseroFileNode *
 brasero_data_project_add_imported_session_file (BraseroDataProject *project,
-						BraseroVolFile *file,
+						GFileInfo *info,
 						BraseroFileNode *parent);
 
 void
