@@ -35,6 +35,8 @@
 #include "brasero-file-monitor.h"
 #include "burn-debug.h"
 
+#include "brasero-file-node.h"
+
 typedef struct _BraseroFileMonitorPrivate BraseroFileMonitorPrivate;
 struct _BraseroFileMonitorPrivate
 {
@@ -229,9 +231,9 @@ brasero_file_monitor_moved_from_event (BraseroFileMonitor *self,
 			
 	/* we remember this move for 5s. If 5s later we haven't received
 	 * a corresponding MOVED_TO then we consider the file was removed. */
-	data->id = g_timeout_add (5000,
-				  (GSourceFunc) brasero_file_monitor_move_timeout_cb,
-				  self);
+	data->id = g_timeout_add_seconds (5,
+					  (GSourceFunc) brasero_file_monitor_move_timeout_cb,
+					  self);
 
 	/* NOTE: the order is important, we _must_ append them */
 	priv->moved_list = g_slist_append (priv->moved_list, data);
@@ -530,8 +532,7 @@ brasero_file_monitor_inotify_monitor_cb (GIOChannel *channel,
 		callback_data = g_hash_table_lookup (priv->files, GINT_TO_POINTER (event.wd));
 		if (!callback_data) {
 			/* Retry with children */
-			callback_data = g_hash_table_lookup (priv->directories,
-							     GINT_TO_POINTER (event.wd));
+			callback_data = g_hash_table_lookup (priv->directories, GINT_TO_POINTER (event.wd));
 			if (name && callback_data) {
 				/* For directories we don't take heed of the SELF events.
 				 * All events are treated through the parent directory
@@ -594,11 +595,12 @@ brasero_file_monitor_start_monitoring_real (BraseroFileMonitor *self,
 	       IN_DELETE_SELF |
 	       IN_MOVE_SELF;
 
+	/* NOTE: always return the same wd when we ask for the same file */
 	wd = inotify_add_watch (dev_fd, path, mask);
 	if (wd == -1) {
 		BRASERO_BURN_LOG ("ERROR creating watch for local file %s : %s\n",
 				  path,
-				  strerror (errno));
+				  g_strerror (errno));
 		g_free (path);
 		return 0;
 	}
@@ -641,6 +643,7 @@ brasero_file_monitor_single_file (BraseroFileMonitor *self,
 	data->callback_data = callback_data;
 	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, data->name);
 
+	/* inotify always return the same wd for the same file */
 	list = g_hash_table_lookup (priv->files, GINT_TO_POINTER (wd));
 	list = g_slist_prepend (list, data);
 	g_hash_table_insert (priv->files,
@@ -693,14 +696,19 @@ brasero_file_monitor_foreach_cancel_file_cb (gpointer key,
 		BraseroInotifyFileData *file_data = NULL;
 
 		file_data = iter->data;
-		if (data->func (data->callback_data, file_data->callback_data)) {
+		if (data->func (file_data->callback_data, data->callback_data)) {
 			BraseroFileMonitorSearchResult *result;
 
 			result = g_new0 (BraseroFileMonitorSearchResult, 1);
 			result->key = key;
 			result->callback_data = file_data;
 			data->results = g_slist_prepend (data->results, result);
-			break;
+
+			/* NOTE: don't stop here as func (at least for data 
+			 * projects returns TRUE when:
+			 * - callback_data is the data looked for
+			 * - when there it is an ancestor
+			 * So it's never finished with just one hit. */
 		}
 	}
 }
@@ -727,6 +735,7 @@ brasero_file_monitor_foreach_cancel (BraseroFileMonitor *self,
 				     gpointer callback_data)
 {
 	GSList *iter;
+	GSList *next;
 	BraseroFileMonitorPrivate *priv;
 	BraseroFileMonitorCancelForeach data;
 
@@ -735,7 +744,7 @@ brasero_file_monitor_foreach_cancel (BraseroFileMonitor *self,
 	data.func = func;
 	data.results = NULL;
 	data.callback_data = callback_data;
-	data.dev_fd = g_io_channel_unix_get_fd (priv->notify);;
+	data.dev_fd = g_io_channel_unix_get_fd (priv->notify);
 
 	g_hash_table_foreach (priv->files,
 			      brasero_file_monitor_foreach_cancel_file_cb,
@@ -765,6 +774,20 @@ brasero_file_monitor_foreach_cancel (BraseroFileMonitor *self,
 	g_hash_table_foreach_remove (priv->directories,
 				     brasero_file_monitor_foreach_cancel_directory_cb,
 				     &data);
+
+	/* Finally get rid of moved that data in moved list */
+	for (iter = priv->moved_list; iter; iter = next) {
+		BraseroInotifyMovedData *data;
+
+		data = iter->data;
+		next = iter->next;
+		if (func (data->callback_data, callback_data)) {
+			priv->moved_list = g_slist_remove (priv->moved_list, data);
+			g_source_remove (data->id);
+			g_free (data->name);
+			g_free (data);
+		}
+	}
 }
 
 static gboolean
@@ -834,7 +857,7 @@ brasero_file_monitor_init (BraseroFileMonitor *object)
 		g_io_channel_unref (priv->notify);
 	}
 	else
-		g_warning ("Failed to open inotify: %s\n", strerror (errno));
+		g_warning ("Failed to open inotify: %s\n", g_strerror (errno));
 }
 
 static void
