@@ -213,15 +213,20 @@ static void
 brasero_project_manager_new_cover_cb (GtkAction *action,
 				      BraseroProjectManager *manager)
 {
+	BraseroJacketEdit *edit;
 	GtkWidget *toplevel;
-	GtkWidget *edit;
+	GtkWidget *dialog;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-	edit = brasero_jacket_edit_dialog_new (toplevel, NULL);
+	dialog = NULL;
+
+	dialog = brasero_jacket_edit_dialog_new (toplevel, &edit);
 
 	if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO)
-		brasero_project_set_cover_specifics (BRASERO_PROJECT (manager->priv->project),
-						     BRASERO_JACKET_EDIT (edit));
+		brasero_project_set_cover_specifics (BRASERO_PROJECT (manager->priv->project), edit);
+
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -868,6 +873,9 @@ brasero_project_manager_open_uri (BraseroProjectManager *manager,
 	/* FIXME: make that asynchronous */
 	/* NOTE: don't follow symlink because we want to identify them */
 	file = g_file_new_for_commandline_arg (uri_arg);
+	if (file)
+		return BRASERO_PROJECT_TYPE_INVALID;
+
 	info = g_file_query_info (file,
 				  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
 				  G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK ","
@@ -876,6 +884,11 @@ brasero_project_manager_open_uri (BraseroProjectManager *manager,
 				  NULL,
 				  NULL);
 
+	if (!info) {
+		g_object_unref (file);
+		return BRASERO_PROJECT_TYPE_INVALID;
+	}
+
 	/* if that's a symlink, redo it on its target to get the real mime type
 	 * that usually also depends on the extension of the target:
 	 * ex: an iso file with the extension .iso will be seen as octet-stream
