@@ -27,23 +27,7 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtktreeviewcolumn.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkradiobutton.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtknotebook.h>
+#include <gtk/gtk.h>
 
 #include "brasero-split-dialog.h"
 #include "brasero-player.h"
@@ -172,12 +156,11 @@ brasero_split_dialog_size_error (BraseroSplitDialog *self)
 					  GTK_BUTTONS_NONE,
 					  _("Do you really want to split the track?"));
 
-	gtk_window_set_title (GTK_WINDOW (message), _("Size Error"));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
 						  _("If you split the track, the size of the new track will be shorter than 6 seconds and will be padded."));
 
 	gtk_dialog_add_button (GTK_DIALOG (message),
-			       _("_Don't split"),
+			       GTK_STOCK_CANCEL,
 			       GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (message),
 			       _("_Split"),
@@ -608,8 +591,8 @@ static void
 brasero_split_dialog_no_silence_message (BraseroSplitDialog *self)
 {
 	brasero_utils_message_dialog (GTK_WIDGET (self),
-				      _("The track wasn't split:"),
-				      _("no silence could be retrieved."),
+				      _("The track wasn't split."),
+				      _("No silence could be detected"),
 				      GTK_MESSAGE_WARNING);
 }
 
@@ -618,8 +601,8 @@ brasero_split_dialog_metadata_finished_cb (BraseroMetadata *metadata,
 					   GError *error,
 					   BraseroSplitDialog *self)
 {
+	BraseroMetadataInfo info = { NULL, };
 	BraseroSplitDialogPrivate *priv;
-	BraseroMetadataInfo info;
 	gboolean added_silence;
 	GSList *iter;
 
@@ -632,13 +615,13 @@ brasero_split_dialog_metadata_finished_cb (BraseroMetadata *metadata,
 
 	if (error) {
 		brasero_utils_message_dialog (GTK_WIDGET (self),
-					      _("An error occured while retrieving silences:"),
+					      _("An error occured while detecting silences."),
 					      error->message,
 					      GTK_MESSAGE_ERROR);
 		return;
 	}
 
-	brasero_metadata_set_info (metadata, &info);
+	brasero_metadata_get_result (metadata, &info, NULL);
 	if (!info.silences) {
 		brasero_split_dialog_no_silence_message (self);
 		return;
@@ -651,6 +634,9 @@ brasero_split_dialog_metadata_finished_cb (BraseroMetadata *metadata,
 
 		silence = iter->data;
 
+		if (!silence)
+			continue;
+
 		if (silence->start >= priv->end)
 			continue;
 
@@ -683,7 +669,10 @@ brasero_split_dialog_metadata_finished_cb (BraseroMetadata *metadata,
 }
 
 static gboolean
-brasero_split_dialog_clear_confirm_dialog (BraseroSplitDialog *self)
+brasero_split_dialog_clear_confirm_dialog (BraseroSplitDialog *self,
+					   const gchar *primary,
+					   const gchar *cancel_button,
+					   const gchar *ok_button)
 {
 	BraseroSplitDialogPrivate *priv;
 	GtkResponseType answer;
@@ -701,17 +690,17 @@ brasero_split_dialog_clear_confirm_dialog (BraseroSplitDialog *self)
 					  GTK_DIALOG_MODAL,
 					  GTK_MESSAGE_QUESTION,
 					  GTK_BUTTONS_NONE,
-					  _("Do you really want to carry on with automatic splitting?"));
+					  "%s",
+					  primary);
 
-	gtk_window_set_title (GTK_WINDOW (message), _("Automatic Split"));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
 						  _("This will remove all previous results."));
 
 	gtk_dialog_add_button (GTK_DIALOG (message),
-			       _("_Don't split"),
+			       cancel_button,
 			       GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (message),
-			       _("_Split"),
+			       ok_button,
 			       GTK_RESPONSE_YES);
 
 	answer = gtk_dialog_run (GTK_DIALOG (message));
@@ -744,7 +733,10 @@ brasero_split_dialog_cut_clicked_cb (GtkButton *button,
 	}
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree));
-	if (!brasero_split_dialog_clear_confirm_dialog (self))
+	if (!brasero_split_dialog_clear_confirm_dialog (self,
+							_("Do you really want to carry on with automatic splitting?"),
+							_("_Don't split"),
+							_("_Split")))
 		return;
 
 	if (page == 1) {
@@ -958,7 +950,10 @@ brasero_split_dialog_reset_clicked_cb (GtkButton *button,
 	GtkTreeModel *model;
 
 	priv = BRASERO_SPLIT_DIALOG_PRIVATE (self);
-	if (!brasero_split_dialog_clear_confirm_dialog (self))
+	if (!brasero_split_dialog_clear_confirm_dialog (self,
+							_("Do you really want to empty the slices preview?"),
+							GTK_STOCK_CANCEL,
+							_("Re_move All")))
 		return;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree));
@@ -1092,7 +1087,7 @@ brasero_split_dialog_init (BraseroSplitDialog *object)
 			  "clicked",
 			  G_CALLBACK (brasero_split_dialog_cut_clicked_cb),
 			  object);
-	gtk_widget_set_tooltip_text (button, _("Press to add a splitting point"));
+	gtk_widget_set_tooltip_text (button, _("Add a splitting point"));
 	priv->cut = button;
 
 	priv->notebook = gtk_notebook_new ();
@@ -1300,6 +1295,7 @@ brasero_split_dialog_init (BraseroSplitDialog *object)
 	g_free (title);
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (priv->combo), 0);
+	g_object_unref (size_group);
 }
 
 static void
