@@ -143,9 +143,9 @@ brasero_src_image_set_track (BraseroSrcImage *dialog,
 			     const gchar *image,
 			     const gchar *toc)
 {
-	gint64 size;
 	gchar *path;
 	gchar *string;
+	gint64 size = 0;
 	gchar *size_string;
 	BraseroSrcImagePrivate *priv;
 
@@ -241,7 +241,7 @@ brasero_src_image_error (BraseroSrcImage *self,
 			 GError *error)
 {
 	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (self)),
-				      _("Please, select another image."),
+				      _("Please select another image."),
 				      error->message,
 				      GTK_MESSAGE_ERROR);
 }
